Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var APPTITLE string
APPTITLE is the name of app displayed in the web UI
var HOSTNAME string
HOSTNAME is the name of the host as displayed with the port in the web UI
Functions ¶
Types ¶
type PageData ¶
type PageData struct {
Authenticated bool
PlayerName string
AppTitle string
Hostname string
Page string
Releases struct {
Flavors []string
Vanilla releases.VersionFile
Paper releases.VersionFile
}
//Servers map[string]server.WebView
Status struct {
Uptime string
}
}
PageData defines data that is passed to HTML templates
Click to show internal directories.
Click to hide internal directories.